@@ -176,6 +176,9 @@ def send_email(params, message):
     logging.warning('Sending email: LHCOPN Source: %s, LHCOPN Destination: %s, message: %s' % (class_transfer_broker_.get_list_src_rcsites(), class_transfer_broker_.get_list_dst_rcsites(), message))
     # Inspect parameters of the transfers and get the metrics of the link
     df_last_event = inspect_transfers(params)
+    if 'src_rcsite' in threading.current_thread().name: filename = params.get('FILENAME PARAMETERS', 'filename_transfers_src')
+    else: filename = params.get('FILENAME PARAMETERS', 'filename_transfers_dst')
+    append_data_to_log_file(filename + '_' + app_timestamp, df_last_event)
     data_gigabytes, throughput_gigabits, parallel_transfers, queued_transfers, timestamp = get_metrics_link(df_last_event)
     # Write content of the email into a txt file
     with open(''.join([os.getcwd(), '/noted/logs/noted_email.txt']), 'w') as f:
@@ -277,6 +280,9 @@ def monitor_queue_before_alert(params, action):
         data_gigabytes, throughput_gigabits, parallel_transfers, queued_transfers, timestamp = get_metrics_link(df_last_event)
         # Count events if there are with different timestamp, i.e. if there are different FTS Optimizer events
         if last_timestamp != str(timestamp):
+            if 'src_rcsite' in threading.current_thread().name: filename = params.get('FILENAME PARAMETERS', 'filename_transfers_src')
+            else: filename = params.get('FILENAME PARAMETERS', 'filename_transfers_dst')
+            append_data_to_log_file(filename + '_' + app_timestamp, df_last_event)
             # Interrupt the start/stop sequence because the throughput changed its expected behaviour
             if (throughput_gigabits < class_transfer_broker_.get_max_throughput() and action == 'start') or (throughput_gigabits > class_transfer_broker_.get_min_throughput() and action == 'stop'): return False
             # Update last timestamp to the new one and count the events
