@@ -4,13 +4,13 @@ echo "------------------------------------------------------------------" >> not
 date >> noted/logs/sense.log
 echo "Received cancel request from NOTED for $2" >> noted/logs/sense.log
 
-STATUS=`noted/sense-o/sense_util.py -s -u $1`
+STATUS=`sense_util.py -s -u $1`
 echo "$2 current status:" ${STATUS} >> noted/logs/sense.log
 
 if [ "$STATUS" = "REINSTATE - READY" ] || [ "$STATUS" = "REINSTATE - COMMITTED" ] || [ "$STATUS" = "CREATE - READY" ]
 then
   echo "$2 is up: OK to cancel" >> noted/logs/sense.log
-  noted/sense-o/sense_util.py -ca -u $1 >> noted/logs/sense.log
+  sense_util.py -ca -u $1 >> noted/logs/sense.log
   date >> noted/logs/sense.log
   echo "$2 done" >> noted/logs/sense.log
 else
